@@ -8,6 +8,7 @@ cd $(dirname ${BASH_SOURCE[0]})/../..
 
 $RM tex/luatex/gregoriotex/gregoriotex-chars.tex
 $RM tex/luatex/gregoriotex/gregoriotex-common.tex
+$RM tex/luatex/gregoriotex/gregoriotex-gsp-default.tex
 $RM tex/luatex/gregoriotex/gregoriotex-main.tex
 $RM tex/luatex/gregoriotex/gregoriotex-nabc.tex
 $RM tex/luatex/gregoriotex/gregoriotex-signs.tex
@@ -15,7 +16,6 @@ $RM tex/luatex/gregoriotex/gregoriotex-spaces.tex
 $RM tex/luatex/gregoriotex/gregoriotex-syllable.tex
 $RM tex/luatex/gregoriotex/gregoriotex-symbols.tex
 $RM tex/luatex/gregoriotex/gregoriotex.tex
-$RM tex/luatex/gregoriotex/gsp-default.tex
 $RM tex/luatex/gregoriotex/gregoriotex-nabc.lua
 $RM tex/luatex/gregoriotex/gregoriotex-signs.lua
 $RM tex/luatex/gregoriotex/gregoriotex-symbols.lua
@@ -46,6 +46,7 @@ $RM doc/luatex/gregoriotex/Command_Index_internal.tex
 $RM doc/luatex/gregoriotex/Gabc.tex
 $RM doc/luatex/gregoriotex/GregorioNabcRef.tex
 $RM doc/luatex/gregoriotex/GregorioRef.tex
+$RM doc/luatex/gregoriotex/gsp-sample.tex
 $RM doc/luatex/gregoriotex/GregorioRef.lua
 $RM doc/luatex/gregoriotex/factus.gabc
 $RM doc/luatex/gregoriotex/omnes.gabc
@@ -71,6 +72,9 @@ $RM fonts/source/gregoriotex/convertsfdtottf.py
 $RM fonts/source/gregoriotex/gregall.sfd
 $RM fonts/source/gregoriotex/gresgmodern.sfd
 $RM fonts/source/gregoriotex/fonts_README.md
+$RM fonts/source/gregoriotex/grelaon.sfd
+$RM fonts/source/gregoriotex/stemsschemas.py
+$RM fonts/source/gregoriotex/simplify.py
 $RM fonts/source/gregoriotex/granapadano-base.sfd
 $RM fonts/source/gregoriotex/greciliae-base.sfd
 $RM fonts/source/gregoriotex/gregorio-base.sfd
@@ -80,3 +84,14 @@ $RM scripts/gregoriotex/uninstall-gtex.sh
 rmdir -p scripts/gregoriotex 2> /dev/null || true
 
 ${TEXHASH}
+$RM doc/luatex/gregoriotex//CHANGELOG.md
+$RM doc/luatex/gregoriotex//CONTRIBUTING.md
+$RM doc/luatex/gregoriotex//CONTRIBUTORS.md
+$RM doc/luatex/gregoriotex//COPYING.md
+$RM doc/luatex/gregoriotex//README.md
+$RM doc/luatex/gregoriotex//UPGRADE.md
+rmdir -p doc/luatex/gregoriotex/ 2> /dev/null || true
+
+$RM source/luatex/gregoriotex//gregorio-6.0.0.zip
+rmdir -p source/luatex/gregoriotex/ 2> /dev/null || true
+
